import { decodeEntities } from '@wordpress/html-entities';
import { useEffect } from '@wordpress/element';
const { registerPaymentMethod } = window.wc.wcBlocksRegistry
const { getSetting } = window.wc.wcSettings

const settings = getSetting( 'apppago_gateway_data', {} )

const labelTitle = decodeEntities( settings.title )
const placeOrderButtonLabel = decodeEntities( settings.placeOrderButtonLabel )

// const Content = () => {
//     return decodeEntities( settings.content || '' )
// }

const Label = ( props ) => {
    const { PaymentMethodLabel, PaymentMethodIcons } = props.components
    return (
        <>
            <PaymentMethodLabel text={ labelTitle } />
            &nbsp;&nbsp;&nbsp;&nbsp;
            <Icon />
        </>
    )
}

const Icon = () => {
    return settings.icon
        ? <img src={settings.icon} style={{ float: 'right', marginRight: '20px' }} />
        : ''
}

const Content = ( props ) => {
    const { eventRegistration, emitResponse } = props;
    const { onPaymentSetup } = eventRegistration;

    useEffect( () => {
        const unsubscribe = onPaymentSetup( async () => {
            // Here we can do any processing we need, and then emit a response.
            // For example, we might validate a custom field, or perform an AJAX request, and then emit a response indicating it is valid or not.
            const taxCodeEl = document.getElementById("apppago_tax_code");
            const clientTypeEl = document.getElementById("apppago_client_type");

            const clientType = clientTypeEl && ["privato", "azienda"].includes(clientTypeEl.value) ? clientTypeEl.value : "privato";

            let labelTaxCode = "Codice Fiscale";
            let regexTaxCode = /^[A-Za-z]{6}[0-9]{2}[A-Za-z][0-9]{2}[A-Za-z][0-9]{3}[A-Za-z]$/;
            if(clientType === "azienda") {
                labelTaxCode = "Partita IVA";
                regexTaxCode = /^[0-9]{11}$/;
            }

            if(!taxCodeEl) {
                return {
                    type: emitResponse.responseTypes.ERROR,
                    message: 'Non esiste il campo ' + labelTaxCode,
                };
            }
            const taxCode = taxCodeEl.value;
            const customDataIsValid = taxCode.match(regexTaxCode);

            if ( customDataIsValid ) {
                return {
                    type: emitResponse.responseTypes.SUCCESS,
                    meta: {
                        paymentMethodData: {
                            'apppago_tax_code': taxCode,
                            'apppago_client_type': clientType,
                        },
                    },
                };
            }

            return {
                type: emitResponse.responseTypes.ERROR,
                message: 'Il campo ' + labelTaxCode + ' non è valido',
            };
        } );
        // Unsubscribes when this component is unmounted.
        return () => {
            unsubscribe();
        };
    }, [
        emitResponse.responseTypes.ERROR,
        emitResponse.responseTypes.SUCCESS,
        onPaymentSetup,
    ] );
        return (
            <div dangerouslySetInnerHTML={{ __html: settings.content }} />
        );
};

registerPaymentMethod( {
    name: "apppago_gateway",
    label: <Label />,
    content: <Content />,
    edit: <Content />,
    canMakePayment: () => true,
    ariaLabel: labelTitle,
    placeOrderButtonLabel: placeOrderButtonLabel,
    supports: {
        features: settings.supports,
    }
} )